## RicoModels                                                             

This is a collection of Neural Network Models that I've tried during my Deep Learning Journey.

### ResNet-20

TODO

### UNet